[−][src]Enum unicode_types::pahawh_hmong::PahawhHmong
An enum to represent all characters in the PahawhHmong block.
Variants
VowelKeeb\u{16b00}: '𖬀'
VowelKeev\u{16b01}: '𖬁'
VowelKib\u{16b02}: '𖬂'
VowelKiv\u{16b03}: '𖬃'
VowelKaub\u{16b04}: '𖬄'
VowelKauv\u{16b05}: '𖬅'
VowelKub\u{16b06}: '𖬆'
VowelKuv\u{16b07}: '𖬇'
VowelKeb\u{16b08}: '𖬈'
VowelKev\u{16b09}: '𖬉'
VowelKaib\u{16b0a}: '𖬊'
VowelKaiv\u{16b0b}: '𖬋'
VowelKoob\u{16b0c}: '𖬌'
VowelKoov\u{16b0d}: '𖬍'
VowelKawb\u{16b0e}: '𖬎'
VowelKawv\u{16b0f}: '𖬏'
VowelKuab\u{16b10}: '𖬐'
VowelKuav\u{16b11}: '𖬑'
VowelKob\u{16b12}: '𖬒'
VowelKov\u{16b13}: '𖬓'
VowelKiab\u{16b14}: '𖬔'
VowelKiav\u{16b15}: '𖬕'
VowelKab\u{16b16}: '𖬖'
VowelKav\u{16b17}: '𖬗'
VowelKwb\u{16b18}: '𖬘'
VowelKwv\u{16b19}: '𖬙'
VowelKaab\u{16b1a}: '𖬚'
VowelKaav\u{16b1b}: '𖬛'
ConsonantVau\u{16b1c}: '𖬜'
ConsonantNtsau\u{16b1d}: '𖬝'
ConsonantLau\u{16b1e}: '𖬞'
ConsonantHau\u{16b1f}: '𖬟'
ConsonantNlau\u{16b20}: '𖬠'
ConsonantRau\u{16b21}: '𖬡'
ConsonantNkau\u{16b22}: '𖬢'
ConsonantQhau\u{16b23}: '𖬣'
ConsonantYau\u{16b24}: '𖬤'
ConsonantHlau\u{16b25}: '𖬥'
ConsonantMau\u{16b26}: '𖬦'
ConsonantChau\u{16b27}: '𖬧'
ConsonantNchau\u{16b28}: '𖬨'
ConsonantHnau\u{16b29}: '𖬩'
ConsonantPlhau\u{16b2a}: '𖬪'
ConsonantNthau\u{16b2b}: '𖬫'
ConsonantNau\u{16b2c}: '𖬬'
ConsonantAu\u{16b2d}: '𖬭'
ConsonantXau\u{16b2e}: '𖬮'
ConsonantCau\u{16b2f}: '𖬯'
MarkCimTub\u{16b30}: '𖬰'
MarkCimSo\u{16b31}: '𖬱'
MarkCimKes\u{16b32}: '𖬲'
MarkCimKhav\u{16b33}: '𖬳'
MarkCimSuam\u{16b34}: '𖬴'
MarkCimHom\u{16b35}: '𖬵'
MarkCimTaum\u{16b36}: '𖬶'
SignVosThom\u{16b37}: '𖬷'
SignVosTshabCeeb\u{16b38}: '𖬸'
SignCimCheem\u{16b39}: '𖬹'
SignVosThiab\u{16b3a}: '𖬺'
SignVosFeem\u{16b3b}: '𖬻'
SignXyeemNtxiv\u{16b3c}: '𖬼'
SignXyeemRho\u{16b3d}: '𖬽'
SignXyeemTov\u{16b3e}: '𖬾'
SignXyeemFaib\u{16b3f}: '𖬿'
SignVosSeev\u{16b40}: '𖭀'
SignMeejSuab\u{16b41}: '𖭁'
SignVosNrua\u{16b42}: '𖭂'
SignIbYam\u{16b43}: '𖭃'
SignXaus\u{16b44}: '𖭄'
SignCimTsovRog\u{16b45}: '𖭅'
DigitZero\u{16b50}: '𖭐'
DigitOne\u{16b51}: '𖭑'
DigitTwo\u{16b52}: '𖭒'
DigitThree\u{16b53}: '𖭓'
DigitFour\u{16b54}: '𖭔'
DigitFive\u{16b55}: '𖭕'
DigitSix\u{16b56}: '𖭖'
DigitSeven\u{16b57}: '𖭗'
DigitEight\u{16b58}: '𖭘'
DigitNine\u{16b59}: '𖭙'
NumberTens\u{16b5b}: '𖭛'
NumberHundreds\u{16b5c}: '𖭜'
NumberTenThousands\u{16b5d}: '𖭝'
NumberMillions\u{16b5e}: '𖭞'
NumberHundredMillions\u{16b5f}: '𖭟'
NumberTenBillions\u{16b60}: '𖭠'
NumberTrillions\u{16b61}: '𖭡'
SignVosLub\u{16b63}: '𖭣'
SignXyoo\u{16b64}: '𖭤'
SignHli\u{16b65}: '𖭥'
SignThirdDashStageHli\u{16b66}: '𖭦'
SignZwjThaj\u{16b67}: '𖭧'
SignHnub\u{16b68}: '𖭨'
SignNqig\u{16b69}: '𖭩'
SignXiab\u{16b6a}: '𖭪'
SignNtuj\u{16b6b}: '𖭫'
SignAv\u{16b6c}: '𖭬'
SignTxheejCeev\u{16b6d}: '𖭭'
SignMeejTseeb\u{16b6e}: '𖭮'
SignTau\u{16b6f}: '𖭯'
SignLos\u{16b70}: '𖭰'
SignMus\u{16b71}: '𖭱'
SignCimHaisLusNtogNtog\u{16b72}: '𖭲'
SignCimCuamTshooj\u{16b73}: '𖭳'
SignCimTxwv\u{16b74}: '𖭴'
SignCimTxwvChwv\u{16b75}: '𖭵'
SignCimPubDawb\u{16b76}: '𖭶'
SignCimNresTos\u{16b77}: '𖭷'
ClanSignTsheej\u{16b7d}: '𖭽'
ClanSignYeeg\u{16b7e}: '𖭾'
ClanSignLis\u{16b7f}: '𖭿'
ClanSignLauj\u{16b80}: '𖮀'
ClanSignXyooj\u{16b81}: '𖮁'
ClanSignKoo\u{16b82}: '𖮂'
ClanSignHawj\u{16b83}: '𖮃'
ClanSignMuas\u{16b84}: '𖮄'
ClanSignThoj\u{16b85}: '𖮅'
ClanSignTsab\u{16b86}: '𖮆'
ClanSignPhab\u{16b87}: '𖮇'
ClanSignKhab\u{16b88}: '𖮈'
ClanSignHam\u{16b89}: '𖮉'
ClanSignVaj\u{16b8a}: '𖮊'
ClanSignFaj\u{16b8b}: '𖮋'
ClanSignYaj\u{16b8c}: '𖮌'
ClanSignTswb\u{16b8d}: '𖮍'
ClanSignKwm\u{16b8e}: '𖮎'
Methods
impl PahawhHmong[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case